@@ -65,8 +65,8 @@ genome_intersect <- function(x, y, by=NULL, mode= "both"){
     # nest around the chromosome column
     x$..index <- seq_len(nrow(x))
     y$..index <- seq_len(nrow(y))
-    nested_x <- tidyr::nest_(x, "x_data", colnames(x)[-1])
-    nested_y <- tidyr::nest_(y, "y_data", colnames(y)[-1])
+    nested_x <- dplyr::group_by_at(x, 1) %>% tidyr::nest()
+    nested_y <- dplyr::group_by_at(y, 1) %>% tidyr::nest()
     by <- c(colnames(nested_y)[1])
     names(by) <- colnames(nested_x)[1]
 
@@ -82,7 +82,7 @@ genome_intersect <- function(x, y, by=NULL, mode= "both"){
                  ..start=IRanges::start(intersection), ..end=IRanges::end(intersection))
     }
 
-    ret <- purrr::map2_df(joined$x_data, joined$y_data, find_overlaps)
+    ret <- purrr::map2_df(joined$data.x, joined$data.y, find_overlaps)
     ret
   }
 
